/* Copyright 2013 Akira Ohta (akohta001@gmail.com)
    This file is part of ntch.

    The ntch is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The ntch is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with ntch.  If not, see <http://www.gnu.org/licenses/>.
    
*/
#ifndef _FILE_H_
#define _FILE_H_
extern BOOL nt_make_sha1_path(const char *base_path,
				const char *org_name, char **outbufp);
extern BOOL nt_mkdir(const char *dir_name);
extern nt_link_tp nt_read_text_file(const char* path);
extern BOOL nt_write_text_file(const char* path, nt_link_tp text);

#endif /* _FILE_H_ */
